var ProvidedDatafileLoader = /** @class */ (function () {
    function ProvidedDatafileLoader(config) {
        this.datafile = config.datafile;
    }
    ProvidedDatafileLoader.prototype.load = function () {
        return this.datafile;
    };
    return ProvidedDatafileLoader;
}());
export { ProvidedDatafileLoader };
var FetchUrlDatafileLoader = /** @class */ (function () {
    function FetchUrlDatafileLoader(config) {
        this.sdkKey = config.sdkKey;
        this.localStorageKey = config.localStorageKey || 'optly_fs_datafile';
    }
    FetchUrlDatafileLoader.prototype.load = function () {
        var _this = this;
        var cacheResult = this.getFromCache();
        var freshDatafileFetch = this.fetchDatafile().then(function (datafile) {
            _this.saveToCache(datafile);
            return datafile;
        });
        if (cacheResult && this.shouldUseCache(cacheResult)) {
            return cacheResult.datafile;
        }
        return freshDatafileFetch;
    };
    FetchUrlDatafileLoader.prototype.saveToCache = function (datafileToSave) {
        var _this = this;
        if (typeof window !== 'undefined') {
            var cacheEntry_1 = {
                datafile: datafileToSave,
                metadata: {
                    timestampCached: Date.now(),
                },
            };
            // use setTimeout as to not block on a potentially expensive JSON.stringify
            setTimeout(function () {
                window.localStorage.setItem(_this.localStorageKey, JSON.stringify(cacheEntry_1));
            }, 0);
        }
    };
    FetchUrlDatafileLoader.prototype.shouldUseCache = function (cacheResult) {
        return (Date.now() - cacheResult.metadata.timestampCached) <= FetchUrlDatafileLoader.MAX_CACHE_AGE_MS;
    };
    FetchUrlDatafileLoader.prototype.fetchDatafile = function () {
        var datafileUrl = "https://cdn.optimizely.com/datafiles/" + this.sdkKey + ".json";
        return new Promise(function (resolve, reject) {
            var req = new XMLHttpRequest();
            req.open(FetchUrlDatafileLoader.GET_METHOD, datafileUrl, true);
            req.onreadystatechange = function () {
                if (req.readyState === FetchUrlDatafileLoader.READY_STATE_COMPLETE) {
                    // TODO: Improve & add more error handling
                    if (req.status >= 400) {
                        reject('Error response fetching datafile');
                        return;
                    }
                    var datafile = void 0;
                    try {
                        datafile = JSON.parse(req.response);
                    }
                    catch (e) {
                        reject("Datafile was not valid JSON. Got: " + req.response);
                        return;
                    }
                    resolve(datafile);
                }
            };
            req.send();
        });
    };
    FetchUrlDatafileLoader.prototype.getFromCache = function () {
        if (typeof window === 'undefined') {
            return null;
        }
        var item = window.localStorage.getItem(this.localStorageKey);
        if (!item) {
            return null;
        }
        var toReturn;
        try {
            toReturn = JSON.parse(item);
        }
        catch (e) {
            toReturn = null;
        }
        return toReturn;
    };
    // 1 week in ms = 7 days * 24 hours * 60 minutes * 60 seconds * 1000 ms
    FetchUrlDatafileLoader.MAX_CACHE_AGE_MS = 7 * 24 * 60 * 60 * 1000;
    FetchUrlDatafileLoader.GET_METHOD = 'GET';
    FetchUrlDatafileLoader.READY_STATE_COMPLETE = 4;
    return FetchUrlDatafileLoader;
}());
export { FetchUrlDatafileLoader };
//# sourceMappingURL=DatafileLoaders.js.map